pub enum Override {
DisabledAtTimestampMs(u64),
Enabled(ManuallyEnabled),
}Variants
DisabledAtTimestampMs(u64)
Enabled(ManuallyEnabled)
Implementations
Sourceimpl Override
impl Override
Sourcepub fn merge(
field: &mut Option<Override>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Override>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.